@@ -1,12 +1,12 @@
-try:
-    from . import data_type
-    from . import i18n
-except ModuleNotFoundError:
-    import data_type
-    import i18n
+from . import data_type
+from . import i18n
 
 
 class Error(Exception):
+    pass
+
+
+class UnknownError(Error):
     def __init__(self, message):
         self.message = message
 
@@ -14,7 +14,7 @@ class Error(Exception):
         return self.message
 
 
-class UnknownError(Exception):
+class RequireLogin(Error):
     def __init__(self, message):
         self.message = message
 
@@ -22,7 +22,7 @@ class UnknownError(Exception):
         return self.message
 
 
-class Requirelogin(Exception):
+class NoPermission(Error):
     def __init__(self, message):
         self.message = message
 
@@ -30,84 +30,76 @@ class Requirelogin(Exception):
         return self.message
 
 
-class NoPermission(Exception):
-    def __init__(self, message):
-        self.message = message
-
-    def __str__(self):
-        return self.message
-
-
-class LoginError(Exception):
+class LoginError(Error):
     def __init__(self):
-        self.message = i18n.loginFail
+        self.message = i18n.login_fail
 
     def __str__(self):
         return self.message
 
 
-class NoFastPush(Exception):
+class NoFastComment(Error):
     def __init__(self):
-        self.message = i18n.NoFastPush
+        self.message = i18n.no_fast_comment
 
     def __str__(self):
         return self.message
 
 
-class NoSuchUser(Exception):
+class NoSuchUser(Error):
     def __init__(self, user):
-        self.message = i18n.NoSuchUser + ': ' + user
+        self.message = i18n.no_such_user + ': ' + user
 
     def __str__(self):
         return self.message
 
 
-class UserOffline(Exception):
-    def __init__(self, user):
-        self.message = i18n.UserOffline + ': ' + user
-
-    def __str__(self):
-        return self.message
-
-
-class ParseError(Exception):
-    def __init__(self, screen):
-        self.message = screen
-
-    def __str__(self):
-        return self.message
-
-
-class NoMoney(Exception):
+class NoSuchMail(Error):
     def __init__(self):
-        self.message = i18n.NoMoney
+        self.message = i18n.no_such_mail
 
     def __str__(self):
         return self.message
 
 
-class MoneyTooFew(Exception):
+# class UserOffline(Error):
+#     def __init__(self, user):
+#         self.message = i18n.user_offline + ': ' + user
+#
+#     def __str__(self):
+#         return self.message
+
+
+# class ParseError(Error):
+#     def __init__(self, screen):
+#         self.message = screen
+#
+#     def __str__(self):
+#         return self.message
+
+
+class NoMoney(Error):
     def __init__(self):
-        self.message = i18n.MoneyTooFew
+        self.message = i18n.no_money
 
     def __str__(self):
         return self.message
 
 
-class NoSuchBoard(Exception):
+class NoSuchBoard(Error):
     def __init__(self, config, board):
-        if config.host == data_type.host_type.PTT1:
+        if config.host == data_type.HOST.PTT1:
             self.message = [
                 i18n.PTT,
-                i18n.NoSuchBoard
+                i18n.no_such_board
             ]
         else:
             self.message = [
                 i18n.PTT2,
-                i18n.NoSuchBoard
+                i18n.no_such_board
             ]
 
-        if config.language == i18n.language.CHINESE:
+        if config.language == data_type.Language.MANDARIN:
             self.message = ''.join(self.message) + ': ' + board
         else:
             self.message = ' '.join(self.message) + ': ' + board
@@ -116,120 +108,106 @@ class NoSuchBoard(Exception):
         return self.message
 
 
-class ConnectionClosed(Exception):
+class ConnectionClosed(Error):
     def __init__(self):
-        self.message = i18n.ConnectionClosed
+        self.message = i18n.connection_closed
 
     def __str__(self):
         return self.message
 
 
-class UnregisteredUser(Exception):
+class UnregisteredUser(Error):
     def __init__(self, api_name):
-        self.message = i18n.UnregisteredUserCantUseThisAPI + ': ' + api_name
+        self.message = i18n.unregistered_user_cant_use_this_api + ': ' + api_name
 
     def __str__(self):
         return self.message
 
 
-class MultiThreadOperated(Exception):
+class MultiThreadOperated(Error):
     def __init__(self):
-        self.message = i18n.MultiThreadOperate
+        self.message = i18n.multi_thread_operate
 
     def __str__(self):
         return self.message
 
 
-class WrongIDorPassword(Exception):
+class WrongIDorPassword(Error):
     def __init__(self):
-        self.message = i18n.ErrorIDPW
+        self.message = i18n.wrong_id_pw
 
     def __str__(self):
         return self.message
 
 
-class WrongPassword(Exception):
+class WrongPassword(Error):
     def __init__(self):
-        self.message = i18n.ErrorPW
+        self.message = i18n.error_pw
 
     def __str__(self):
         return self.message
 
 
-class LoginTooOften(Exception):
+class LoginTooOften(Error):
     def __init__(self):
-        self.message = i18n.LoginTooOften
+        self.message = i18n.login_too_often
 
     def __str__(self):
         return self.message
 
 
-class UseTooManyResources(Exception):
+class UseTooManyResources(Error):
     def __init__(self):
-        self.message = i18n.UseTooManyResources
+        self.message = i18n.use_too_many_resources
 
     def __str__(self):
         return self.message
 
 
-class HostNotSupport(Exception):
+class HostNotSupport(Error):
     def __init__(self, api):
-        self.message = f'{i18n.PTT2NotSupport}: {api}'
+        self.message = f'{i18n.ptt2_not_support}: {api}'
 
     def __str__(self):
         return self.message
 
 
-class NoPush(Exception):
+class CantComment(Error):
     def __init__(self):
-        self.message = i18n.NoPush
+        self.message = i18n.no_comment
 
     def __str__(self):
         return self.message
 
 
-class NoResponse(Exception):
+class CantResponse(Error):
     def __init__(self):
-        self.message = i18n.NoResponse
+        self.message = i18n.no_response
 
     def __str__(self):
         return self.message
 
 
-class NeedModeratorPermission(Exception):
+class NeedModeratorPermission(Error):
     def __init__(self, board):
-        self.message = f'{i18n.NeedModeratorPermission}: {board}'
+        self.message = f'{i18n.need_moderator_permission}: {board}'
 
     def __str__(self):
         return self.message
 
 
-class ConnectError(Exception):
+class ConnectError(Error):
     def __init__(self, config):
-        self.message = [i18n.Connect, i18n.Fail]
-
-        if config.language == i18n.language.CHINESE:
-            self.message = ''.join(self.message)
-        else:
-            self.message = ' '.join(self.message)
+        self.message = i18n.connect_fail
 
     def __str__(self):
         return self.message
 
 
-class NoMatchTargetError(Exception):
-    def __init__(self, screen_queue: list):
-        self.ScreenQueue = screen_queue
-
-    def __str__(self):
-        screens = ('\n' + '-' * 50 + '\n').join(self.ScreenQueue.get(3))
-        return screens + '\n' + i18n.ScreenNoMatchTarget
-
-
-class NoSuchPost(Exception):
+class NoSuchPost(Error):
     def __init__(self, board, aid):
         self.message = i18n.replace(
-            i18n.NoSuchPost,
+            i18n.no_such_post,
             board,
             aid)
 
@@ -237,41 +215,37 @@ class NoSuchPost(Exception):
         return self.message
 
 
-class CanNotUseSearchPostCode(Exception):
+class CanNotUseSearchPostCode(Error):
+    """
+    此狀態下無法使用搜尋文章代碼(AID)功能
+    """
+
     def __init__(self):
-        self.message = i18n.CanNotUseSearchPostCodeF
+        self.message = i18n.can_not_use_search_post_code_f
 
     def __str__(self):
         return self.message
 
 
-class UserHasPreviouslyBeenBanned(Exception):
+class UserHasPreviouslyBeenBanned(Error):
     def __init__(self):
-        self.message = i18n.UserHasPreviouslyBeenBanned
+        self.message = i18n.user_has_previously_been_banned
 
     def __str__(self):
         return self.message
 
 
-class MailboxFull(Exception):
+class MailboxFull(Error):
     def __init__(self):
-        self.message = i18n.MailBoxFull
+        self.message = i18n.mail_box_full
 
     def __str__(self):
         return self.message
 
 
-class Timeout(Exception):
+class NoSearchResult(Error):
     def __init__(self):
-        self.message = i18n.timeout
-
-    def __str__(self):
-        return self.message
-
-
-class NoSearchResult(Exception):
-    def __init__(self):
-        self.message = i18n.NoSearchResult
+        self.message = i18n.no_search_result
 
     def __str__(self):
         return self.message
@@ -279,26 +253,15 @@ class NoSearchResult(Exception):
 
 # 此帳號已設定為只能使用安全連線
 
-class OnlySecureConnection(Exception):
+class OnlySecureConnection(Error):
     def __init__(self):
-        self.message = i18n.OnlySecureConnection
+        self.message = i18n.only_secure_connection
 
     def __str__(self):
         return self.message
 
 
-class DeletedPost(Exception):
-    def __init__(self, board, aid):
-        self.message = i18n.replace(
-            i18n.DeletedPost,
-            board,
-            aid)
-
-    def __str__(self):
-        return self.message
-
-
-class set_connect_mail_first(Exception):
+class SetConnectMailFirst(Error):
     def __init__(self):
         self.message = i18n.set_connect_mail_first
 
